Module: Google::Cloud::ServiceControl

Defined in:
lib/google/cloud/service_control.rb,
lib/google/cloud/service_control/version.rb

Constant Summary collapse

VERSION =
"1.7.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.service_control| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-service_control library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



223
224
225
226
227
# File 'lib/google/cloud/service_control.rb', line 223

def self.configure
  yield ::Google::Cloud.configure.service_control if block_given?

  ::Google::Cloud.configure.service_control
end

.quota_controller(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for QuotaController.

By default, this returns an instance of Google::Cloud::ServiceControl::V1::QuotaController::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the QuotaController service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the QuotaController service. You can determine whether the method will succeed by calling quota_controller_available?.

About QuotaController

Google Quota Control API

Allows clients to allocate and release quota against a managed service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/google/cloud/service_control.rb', line 78

def self.quota_controller version: :v1, transport: :grpc, &block
  require "google/cloud/service_control/#{version.to_s.downcase}"

  package_name = Google::Cloud::ServiceControl
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::ServiceControl.const_get(package_name).const_get(:QuotaController)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.quota_controller_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the QuotaController service is supported by the current client. If true, you can retrieve a client object by calling quota_controller. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the QuotaController service, or if the versioned client gem needs an update to support the QuotaController service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/google/cloud/service_control.rb', line 102

def self.quota_controller_available? version: :v1, transport: :grpc
  require "google/cloud/service_control/#{version.to_s.downcase}"
  package_name = Google::Cloud::ServiceControl
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::ServiceControl.const_get package_name
  return false unless service_module.const_defined? :QuotaController
  service_module = service_module.const_get :QuotaController
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end

.service_controller(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for ServiceController.

By default, this returns an instance of Google::Cloud::ServiceControl::V1::ServiceController::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the ServiceController service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ServiceController service. You can determine whether the method will succeed by calling service_controller_available?.

About ServiceController

Google Service Control API

Lets clients check and report operations against a managed service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



151
152
153
154
155
156
157
158
159
160
161
# File 'lib/google/cloud/service_control.rb', line 151

def self.service_controller version: :v1, transport: :grpc, &block
  require "google/cloud/service_control/#{version.to_s.downcase}"

  package_name = Google::Cloud::ServiceControl
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::ServiceControl.const_get(package_name).const_get(:ServiceController)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.service_controller_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the ServiceController service is supported by the current client. If true, you can retrieve a client object by calling service_controller. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ServiceController service, or if the versioned client gem needs an update to support the ServiceController service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/google/cloud/service_control.rb', line 175

def self.service_controller_available? version: :v1, transport: :grpc
  require "google/cloud/service_control/#{version.to_s.downcase}"
  package_name = Google::Cloud::ServiceControl
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::ServiceControl.const_get package_name
  return false unless service_module.const_defined? :ServiceController
  service_module = service_module.const_get :ServiceController
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end